<!DOCTYPE TS><TS>
<context>
    <name></name>
    <message>
        <source>Error in config.py:</source>
        <translation>config.py 中有錯誤：</translation>
    </message>
    <message>
        <source>Error when running plugin:</source>
        <translation>執行插件時出錯：</translation>
    </message>
    <message>
        <source>Unable to load file.</source>
        <translation>無法載入檔案。</translation>
    </message>
    <message>
        <source>Invalid file format.</source>
        <translation>無效的檔案格式。</translation>
    </message>
    <message>
        <source>Unable to save file.</source>
        <translation>無法儲存檔案。</translation>
    </message>
    <message>
        <source>Unable to parse XML:</source>
        <translation>無法解析XML：</translation>
    </message>
    <message>
        <source>Unrecognised encoding.</source>
        <translation>無法識別的編碼。</translation>
    </message>
    <message>
        <source>Missing answer on line:</source>
        <translation>在行上缺少答案：</translation>
    </message>
    <message>
        <source>Unable to load database.
Creating tmp file.</source>
        <translation>無法載入資料程式庫。建立暫存檔。</translation>
    </message>
    <message>
        <source>Mnemosyne</source>
        <translation>Mnemosyne</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>確認(&amp;O)</translation>
    </message>
    <message>
        <source>File exists:</source>
        <translation>檔案已存在：</translation>
    </message>
    <message>
        <source>&amp;Overwrite</source>
        <translation>覆寫(&amp;O)</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>取消(&amp;C)</translation>
    </message>
    <message>
        <source>Removed duplicates: </source>
        <translation>移除的重複項： </translation>
    </message>
    <message>
        <source>There are cards with different answers for question:

</source>
        <translation>有卡片對問題有不同答案：

</translation>
    </message>
    <message>
        <source>&amp;Merge and edit</source>
        <translation>合併后編輯(&amp;M)</translation>
    </message>
    <message>
        <source>&amp;Don&apos;t merge</source>
        <translation>不要合併(&amp;D)</translation>
    </message>
    <message>
        <source>Done!</source>
        <translation>完成！</translation>
    </message>
    <message>
        <source>You don&apos;t remember this card yet.</source>
        <translation>你還不記得這張卡片。</translation>
    </message>
    <message>
        <source>Like &apos;0&apos;, but it&apos;s getting more familiar.</source>
        <translation>類似于‘0’，但它正變得更熟悉。</translation>
    </message>
    <message>
        <source> Show it less often.</source>
        <translation>更少地察看它。</translation>
    </message>
    <message>
        <source>You&apos;ve memorised this card now,</source>
        <translation>現在你記下了這張卡片，</translation>
    </message>
    <message>
        <source> and will probably remember it for a few days.</source>
        <translation>并可能記住几天。</translation>
    </message>
    <message>
        <source>You have forgotten this card completely.</source>
        <translation>你完全忘記了這張卡片。</translation>
    </message>
    <message>
        <source>Barely correct answer. The interval was way too long.</source>
        <translation>勉強正確的答案。間隔的時間實在太長了。</translation>
    </message>
    <message>
        <source>Correct answer, but with much effort.</source>
        <translation>正確的答案，但非常費勁。</translation>
    </message>
    <message>
        <source> The interval was probably too long.</source>
        <translation>間隔的時間可能太長了。</translation>
    </message>
    <message>
        <source>Correct answer, with some effort.</source>
        <translation>正確的答案，需要稍作努力。</translation>
    </message>
    <message>
        <source> The interval was probably just right.</source>
        <translation>間隔的時間可能正好。</translation>
    </message>
    <message>
        <source>Correct answer, but without any</source>
        <translation>正確的答案，但沒有任何</translation>
    </message>
    <message>
        <source> difficulties. The interval was probably too short.</source>
        <translation>困難。間隔的時間可能太短了。</translation>
    </message>
</context>
<context>
    <name>AboutDlg</name>
    <message>
        <source>Mnemosyne</source>
        <translation>Mnemosyne</translation>
    </message>
    <message>
        <source>Main author: Peter Bienstman

</source>
        <translation>主要作者： Peter Bienstman

</translation>
    </message>
    <message>
        <source>More info: http://mnemosyne-proj.sourceforge.net
</source>
        <translation type="obsolete">更多資訊： http://mnemosyne-proj.sourceforge.net
</translation>
    </message>
    <message>
        <source>More info: http://mnemosyne-proj.org
</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AboutFrm</name>
    <message>
        <source>About</source>
        <translation>關于</translation>
    </message>
</context>
<context>
    <name>ActivateCategoriesFrm</name>
    <message>
        <source>Activate categories</source>
        <translation>啟動分類</translation>
    </message>
    <message>
        <source>Select the categories to activate:</source>
        <translation>選取要啟動的分類：</translation>
    </message>
    <message>
        <source>Activate none</source>
        <translation>無一啟動</translation>
    </message>
    <message>
        <source>Activate all</source>
        <translation>全部啟動</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>確認(&amp;O)</translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation>Alt+O</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>取消(&amp;C)</translation>
    </message>
</context>
<context>
    <name>AddItemsDlg</name>
    <message>
        <source>&lt;default&gt;</source>
        <translation>&lt;預設&gt;</translation>
    </message>
    <message>
        <source>Mnemosyne</source>
        <translation>Mnemosyne</translation>
    </message>
    <message>
        <source>Abandon current card?</source>
        <translation>放棄目前卡片？</translation>
    </message>
    <message>
        <source>&amp;Yes</source>
        <translation>是(&amp;Y)</translation>
    </message>
    <message>
        <source>&amp;No</source>
        <translation>否(&amp;N)</translation>
    </message>
    <message>
        <source>Question:</source>
        <translation>問題：</translation>
    </message>
    <message>
        <source>Answer:</source>
        <translation>答案：</translation>
    </message>
    <message>
        <source>Written form:</source>
        <translation>文字形式：</translation>
    </message>
    <message>
        <source>Translation:</source>
        <translation>翻譯：</translation>
    </message>
    <message>
        <source>Card is already in database.
</source>
        <translation>卡片已在資料程式庫中。
</translation>
    </message>
    <message>
        <source>Duplicate not added.</source>
        <translation>重複項沒有被添加。</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>確認(&amp;O)</translation>
    </message>
    <message>
        <source>There are different answers for</source>
        <translation>有不同答案回答了</translation>
    </message>
    <message>
        <source> this question:

</source>
        <translation>這個問題：

</translation>
    </message>
    <message>
        <source>&amp;Merge and edit</source>
        <translation>合併后編輯(&amp;M)</translation>
    </message>
    <message>
        <source>&amp;Add as is</source>
        <translation>照此添加(&amp;A)</translation>
    </message>
    <message>
        <source>&amp;Do not add</source>
        <translation>不要添加(&amp;D)</translation>
    </message>
</context>
<context>
    <name>AddItemsFrm</name>
    <message>
        <source>Add cards</source>
        <translation>添加卡片</translation>
    </message>
    <message>
        <source>Category:</source>
        <translation>分類：</translation>
    </message>
    <message>
        <source>Question:</source>
        <translation>問題：</translation>
    </message>
    <message>
        <source>Pronunciation:</source>
        <translation>發音：</translation>
    </message>
    <message>
        <source>Answer:</source>
        <translation>答案：</translation>
    </message>
    <message>
        <source>Add &amp;vice versa too</source>
        <translation>也添加相反卡片(&amp;V)</translation>
    </message>
    <message>
        <source>Alt+V</source>
        <translation>Alt+V</translation>
    </message>
    <message>
        <source>Select initial grade:</source>
        <translation>選取初始評分：</translation>
    </message>
    <message>
        <source>&amp;0</source>
        <translation>&amp;0</translation>
    </message>
    <message>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <source>You don&apos;t remember this item yet or forgot it.</source>
        <translation>你還不記得這張卡片或者忘記了。</translation>
    </message>
    <message>
        <source>&amp;1</source>
        <translation>&amp;1</translation>
    </message>
    <message>
        <source>Ctrl+1</source>
        <translation>Ctrl+1</translation>
    </message>
    <message>
        <source>Like &apos;0&apos;, but the item is getting more familiar.</source>
        <translation>類似于‘0’，但它正變得更熟悉。</translation>
    </message>
    <message>
        <source>&amp;2</source>
        <translation>&amp;2</translation>
    </message>
    <message>
        <source>Ctrl+2</source>
        <translation>Ctrl+2</translation>
    </message>
    <message>
        <source>You&apos;ve memorised this item now, and will probably remember it for a few days.</source>
        <translation>現在你記下了這張卡片，并可能記住几天。</translation>
    </message>
    <message>
        <source>&amp;3</source>
        <translation>&amp;3</translation>
    </message>
    <message>
        <source>Ctrl+3</source>
        <translation>Ctrl+3</translation>
    </message>
    <message>
        <source>Correct answer, but with much effort. The interval was probably too long</source>
        <translation>正確的答案，但非常費勁。間隔的時間可能太長了。</translation>
    </message>
    <message>
        <source>&amp;4</source>
        <translation>&amp;4</translation>
    </message>
    <message>
        <source>Ctrl+4</source>
        <translation>Ctrl+4</translation>
    </message>
    <message>
        <source>Correct answer, with some effort. The interval was probably just right.</source>
        <translation>正確的答案，需要稍作努力。間隔的時間可能正好。</translation>
    </message>
    <message>
        <source>&amp;5</source>
        <translation>&amp;5</translation>
    </message>
    <message>
        <source>Ctrl+5</source>
        <translation>Ctrl+5</translation>
    </message>
    <message>
        <source>Correct answer, but without any difficulties. The interval was probably too short.</source>
        <translation>正確的答案，但沒有任何困難。間隔的時間可能太短了。</translation>
    </message>
    <message>
        <source>Type question and answer, then pick initial grade.</source>
        <translation>匯入問題和答案，然后選取初始評分。</translation>
    </message>
    <message>
        <source>&amp;Preview</source>
        <translation type="obsolete">預覽(&amp;P)</translation>
    </message>
    <message>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>結束(&amp;X)</translation>
    </message>
    <message>
        <source>Alt+X</source>
        <translation>Alt+X</translation>
    </message>
    <message>
        <source>Preview</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ChangeCategoryFrm</name>
    <message>
        <source>Change category</source>
        <translation>變更分類</translation>
    </message>
    <message>
        <source>Category:</source>
        <translation>分類：</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>確認(&amp;O)</translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation>Alt+O</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>取消(&amp;C)</translation>
    </message>
    <message>
        <source>Alt+C</source>
        <translation>Alt+C</translation>
    </message>
</context>
<context>
    <name>ConfigurationFrm</name>
    <message>
        <source>Mnemosyne configuration</source>
        <translation>Mnemosyne 配置</translation>
    </message>
    <message>
        <source>Hover with the mouse over the buttons to get extra information.</source>
        <translation>把滑鼠指標懸停在按鈕上來獲得其餘資訊。</translation>
    </message>
    <message>
        <source>Appearance</source>
        <translation>外觀</translation>
    </message>
    <message>
        <source>Set Q/A font</source>
        <translation>設定問題／答案字型</translation>
    </message>
    <message>
        <source>Set the font used when showing single questions and answers</source>
        <translation>設定用于察看單個問題和答案的字型</translation>
    </message>
    <message>
        <source>Set list font</source>
        <translation>設定清單字型</translation>
    </message>
    <message>
        <source>Set the font used when showing the list of all the cards in the deck</source>
        <translation>設定用于察看卡片疊中所有卡片清單的字型</translation>
    </message>
    <message>
        <source>Increase size of non-latin characters by</source>
        <translation>增加非拉丁字元大小</translation>
    </message>
    <message>
        <source>Sometimes complex glyphs are hard to read at the default latin font size</source>
        <translation>複雜的象徵式用預設的拉丁字型大小往往很難讀</translation>
    </message>
    <message>
        <source>point(s)</source>
        <translation>磅(pt)</translation>
    </message>
    <message>
        <source>Log uploading</source>
        <translation>日誌上傳</translation>
    </message>
    <message>
        <source>Upload anonymous logs</source>
        <translation>上傳匿名日誌</translation>
    </message>
    <message>
        <source>Share anonymous statistics to contribute to memory research</source>
        <translation>分享匿名統計資訊來為記憶研究做貢獻</translation>
    </message>
    <message>
        <source>Duplicate handling</source>
        <translation>重複項處理</translation>
    </message>
    <message>
        <source>Check for duplicates when adding new cards</source>
        <translation>添加新卡片時檢查重複項</translation>
    </message>
    <message>
        <source>Allow duplicates in different categories</source>
        <translation>允許不同分類中有重複項</translation>
    </message>
    <message>
        <source>Repetition process</source>
        <translation>重複過程</translation>
    </message>
    <message>
        <source>Number of grade 0 cards to learn at once:</source>
        <translation type="obsolete">一次學習0分卡片數量：</translation>
    </message>
    <message>
        <source>Note: this is NOT the number of grade 0 cards you want to memorise *per day*</source>
        <translation>注意：這并不是你 *每天* 想要記下的0分卡片數量</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>確認(&amp;O)</translation>
    </message>
    <message>
        <source>Defaults</source>
        <translation>預設設定</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>取消(&amp;C)</translation>
    </message>
    <message>
        <source>Learn new cards in random order</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Number of grade 0 cards to hold in your hand:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditItemFrm</name>
    <message>
        <source>Edit card</source>
        <translation>編輯卡片</translation>
    </message>
    <message>
        <source>Category:</source>
        <translation>分類：</translation>
    </message>
    <message>
        <source>Question:</source>
        <translation>問題：</translation>
    </message>
    <message>
        <source>Answer:</source>
        <translation>答案：</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>確認(&amp;O)</translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation>Alt+O</translation>
    </message>
    <message>
        <source>&amp;Preview</source>
        <translation>預覽(&amp;P)</translation>
    </message>
    <message>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>取消(&amp;C)</translation>
    </message>
    <message>
        <source>Alt+C</source>
        <translation>Alt+C</translation>
    </message>
</context>
<context>
    <name>EditItemsDlg</name>
    <message>
        <source>Please wait...</source>
        <translation>請稍候...</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>編輯(&amp;E)</translation>
    </message>
    <message>
        <source>Ctrl+E</source>
        <translation>Ctrl+E</translation>
    </message>
    <message>
        <source>&amp;Preview</source>
        <translation>預覽(&amp;P)</translation>
    </message>
    <message>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <source>&amp;Add vice versa</source>
        <translation>添加相反卡片(&amp;A)</translation>
    </message>
    <message>
        <source>S&amp;tatistics</source>
        <translation>統計(&amp;T)</translation>
    </message>
    <message>
        <source>Ctrl+T</source>
        <translation>Ctrl+T</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>移除(&amp;D)</translation>
    </message>
    <message>
        <source>&amp;Change category</source>
        <translation>變更分類(&amp;C)</translation>
    </message>
    <message>
        <source>Add &amp;vice versa</source>
        <translation>添加相反卡片(&amp;V)</translation>
    </message>
    <message>
        <source>Add vice versa of these cards?</source>
        <translation>為這些卡片添加相反卡片？</translation>
    </message>
    <message>
        <source>Add vice versa of this card?</source>
        <translation>為這張卡片添加相反卡片？</translation>
    </message>
    <message>
        <source>Mnemosyne</source>
        <translation>Mnemosyne</translation>
    </message>
    <message>
        <source>

This could create duplicates if the vice </source>
        <translation>

如果已經存在相反卡片，</translation>
    </message>
    <message>
        <source>versas are already present, 
so you might want to run </source>
        <translation>就會產生重複卡片，因此之后你可能要執行</translation>
    </message>
    <message>
        <source>clean duplicates&apos; afterwards.</source>
        <translation>清除重複卡片。</translation>
    </message>
    <message>
        <source>&amp;Yes</source>
        <translation>是(&amp;Y)</translation>
    </message>
    <message>
        <source>&amp;No</source>
        <translation>否(&amp;N)</translation>
    </message>
    <message>
        <source>Grade:</source>
        <translation>評分：</translation>
    </message>
    <message>
        <source>Easiness:</source>
        <translation>容易程度：</translation>
    </message>
    <message>
        <source>Repetitions:</source>
        <translation>重複次數：</translation>
    </message>
    <message>
        <source>Lapses:</source>
        <translation>錯過次數：</translation>
    </message>
    <message>
        <source>Days since last repetition:</source>
        <translation>自從上次重複的天數：</translation>
    </message>
    <message>
        <source>Days until next repetition:</source>
        <translation>直到下次重複的天數：</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>確認(&amp;O)</translation>
    </message>
    <message>
        <source>Delete these cards?</source>
        <translation>移除這些卡片？</translation>
    </message>
    <message>
        <source>Delete this card?</source>
        <translation>移除這張卡片？</translation>
    </message>
    <message>
        <source>The text you entered was not found.</source>
        <translation>你所匯入的字檔沒有找到。</translation>
    </message>
    <message>
        <source>&amp;Find again</source>
        <translation>再找(&amp;F)</translation>
    </message>
    <message>
        <source>F</source>
        <translation>F</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>尋找(&amp;F)</translation>
    </message>
    <message>
        <source>Alt+F</source>
        <translation type="obsolete"></translation>
    </message>
</context>
<context>
    <name>EditItemsFrm</name>
    <message>
        <source>Question</source>
        <translation>問題</translation>
    </message>
    <message>
        <source>Answer</source>
        <translation>答案</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>分類</translation>
    </message>
    <message>
        <source>Edit deck</source>
        <translation>編輯卡片疊</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>尋找(&amp;F)</translation>
    </message>
    <message>
        <source>To edit a card, right-click on it.</source>
        <translation>要編輯一張卡片，請右擊它。</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>結束(&amp;X)</translation>
    </message>
    <message>
        <source>Alt+X</source>
        <translation>Alt+X</translation>
    </message>
    <message>
        <source>Alt+F</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ExportDlg</name>
    <message>
        <source>All Files (*);;</source>
        <translation>所有檔案 (*);;</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>導出</translation>
    </message>
</context>
<context>
    <name>ExportFrm</name>
    <message>
        <source>Export to file</source>
        <translation>導出到檔案</translation>
    </message>
    <message>
        <source>File format:</source>
        <translation>檔案格式：</translation>
    </message>
    <message>
        <source>File to export to:</source>
        <translation>導出到檔案：</translation>
    </message>
    <message>
        <source>&amp;Browse</source>
        <translation>瀏覽(&amp;B)</translation>
    </message>
    <message>
        <source>Categories to export:</source>
        <translation>要導出的分類：</translation>
    </message>
    <message>
        <source>&amp;Select all</source>
        <translation>選取全部(&amp;S)</translation>
    </message>
    <message>
        <source>Reset learning data on export</source>
        <translation>導出時重置學習資料</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>確認(&amp;O)</translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation>Alt+O</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>取消(&amp;C)</translation>
    </message>
</context>
<context>
    <name>ImportDlg</name>
    <message>
        <source>&lt;default&gt;</source>
        <translation>&lt;預設&gt;</translation>
    </message>
    <message>
        <source>All Files (*);;</source>
        <translation>所有檔案 (*);;</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>導入</translation>
    </message>
</context>
<context>
    <name>ImportFrm</name>
    <message>
        <source>Import from file</source>
        <translation>從檔案導入</translation>
    </message>
    <message>
        <source>File format:</source>
        <translation>檔案格式：</translation>
    </message>
    <message>
        <source>File to import from:</source>
        <translation>從檔案導入：</translation>
    </message>
    <message>
        <source>&amp;Browse</source>
        <translation>瀏覽(&amp;B)</translation>
    </message>
    <message>
        <source>Put cards without category into this category:</source>
        <translation>將沒有分類的卡片放到這個分類中：</translation>
    </message>
    <message>
        <source>Note: all cards will be added to the current database.</source>
        <translation>注意：所有卡片將被添加到目前資料程式庫。</translation>
    </message>
    <message>
        <source>Reset learning data on import</source>
        <translation>導入時重置學習資料</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>確認(&amp;O)</translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation>Alt+O</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>取消(&amp;C)</translation>
    </message>
</context>
<context>
    <name>MainDlg</name>
    <message>
        <source>Mnemosyne databases (*.mem)</source>
        <translation>Mnemosyne 資料程式庫 (*.mem)</translation>
    </message>
    <message>
        <source>New</source>
        <translation>新建</translation>
    </message>
    <message>
        <source>Please wait...</source>
        <translation>請稍候...</translation>
    </message>
    <message>
        <source>Mnemosyne</source>
        <translation>Mnemosyne</translation>
    </message>
    <message>
        <source>Delete current card?</source>
        <translation>移除目前卡片？</translation>
    </message>
    <message>
        <source>&amp;Yes</source>
        <translation>是(&amp;Y)</translation>
    </message>
    <message>
        <source>&amp;No</source>
        <translation>否(&amp;N)</translation>
    </message>
    <message>
        <source>Returns in </source>
        <translation>在</translation>
    </message>
    <message>
        <source> day(s).</source>
        <translation>天后傳回。</translation>
    </message>
    <message>
        <source>Next repetition: today.</source>
        <translation>下次重複：今天。</translation>
    </message>
    <message>
        <source>Next repetition: tomorrow.</source>
        <translation>下次重複：明天。</translation>
    </message>
    <message>
        <source>Next repetition in </source>
        <translation>下次重複在</translation>
    </message>
    <message>
        <source> days.</source>
        <translation>天后。</translation>
    </message>
    <message>
        <source>Question:</source>
        <translation>問題：</translation>
    </message>
    <message>
        <source>&lt;default&gt;</source>
        <translation>&lt;預設&gt;</translation>
    </message>
    <message>
        <source>Show &amp;answer</source>
        <translation type="obsolete">察看答案(&amp;A)</translation>
    </message>
    <message>
        <source>Learn ahead of schedule</source>
        <translation>提前學習</translation>
    </message>
    <message>
        <source>Pick days until next repetition:</source>
        <translation>選取直到下次重複的天數：</translation>
    </message>
    <message>
        <source>Grade your answer:</source>
        <translation>給你的答案評分：</translation>
    </message>
    <message>
        <source>Scheduled: </source>
        <translation>計划：</translation>
    </message>
    <message>
        <source>Not memorised: </source>
        <translation>未記：</translation>
    </message>
    <message>
        <source>All: </source>
        <translation>所有：</translation>
    </message>
    <message>
        <source>Show answer</source>
        <translation type="unfinished">察看答案</translation>
    </message>
</context>
<context>
    <name>MainFrm</name>
    <message>
        <source>Mnemosyne</source>
        <translation>Mnemosyne</translation>
    </message>
    <message>
        <source>Question:</source>
        <translation>問題：</translation>
    </message>
    <message>
        <source>Answer:</source>
        <translation>答案：</translation>
    </message>
    <message>
        <source>Show answer</source>
        <translation>察看答案</translation>
    </message>
    <message>
        <source>Grade your answer:</source>
        <translation>給你的答案評分：</translation>
    </message>
    <message>
        <source>&amp;0</source>
        <translation>&amp;0</translation>
    </message>
    <message>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <source>&amp;1</source>
        <translation>&amp;1</translation>
    </message>
    <message>
        <source>1</source>
        <translation>1</translation>
    </message>
    <message>
        <source>&amp;2</source>
        <translation>&amp;2</translation>
    </message>
    <message>
        <source>2</source>
        <translation>2</translation>
    </message>
    <message>
        <source>&amp;3</source>
        <translation>&amp;3</translation>
    </message>
    <message>
        <source>3</source>
        <translation>3</translation>
    </message>
    <message>
        <source>&amp;4</source>
        <translation>&amp;4</translation>
    </message>
    <message>
        <source>4</source>
        <translation>4</translation>
    </message>
    <message>
        <source>&amp;5</source>
        <translation>&amp;5</translation>
    </message>
    <message>
        <source>5</source>
        <translation>5</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>新建(&amp;N)</translation>
    </message>
    <message>
        <source>.</source>
        <translation>.</translation>
    </message>
    <message>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <source>&amp;Open...</source>
        <translation>開啟(&amp;O)...</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>儲存(&amp;S)</translation>
    </message>
    <message>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <source>Save &amp;As...</source>
        <translation>存新檔(&amp;A)...</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>結束(&amp;X)</translation>
    </message>
    <message>
        <source>About</source>
        <translation>關于</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>關于(&amp;A)</translation>
    </message>
    <message>
        <source>Add cards</source>
        <translation>添加卡片</translation>
    </message>
    <message>
        <source>&amp;Add cards</source>
        <translation>添加卡片(&amp;A)</translation>
    </message>
    <message>
        <source>Ctrl+A</source>
        <translation>Ctrl+A</translation>
    </message>
    <message>
        <source>Activate cate&amp;gories</source>
        <translation>啟動分類(&amp;G)</translation>
    </message>
    <message>
        <source>Edit deck</source>
        <translation>編輯卡片疊</translation>
    </message>
    <message>
        <source>Edit &amp;deck</source>
        <translation>編輯卡片疊(&amp;D)</translation>
    </message>
    <message>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
    <message>
        <source>&amp;Import</source>
        <translation>導入(&amp;I)</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation>導出(&amp;E)</translation>
    </message>
    <message>
        <source>Show &amp;toolbar</source>
        <translation>察看工具軸(&amp;T)</translation>
    </message>
    <message>
        <source>Edit current card</source>
        <translation>編輯目前卡片</translation>
    </message>
    <message>
        <source>&amp;Edit current card</source>
        <translation>編輯目前卡片(&amp;E)</translation>
    </message>
    <message>
        <source>Ctrl+E</source>
        <translation>Ctrl+E</translation>
    </message>
    <message>
        <source>Delete current card</source>
        <translation>移除目前卡片</translation>
    </message>
    <message>
        <source>&amp;Delete current card</source>
        <translation>移除目前卡片(&amp;D)</translation>
    </message>
    <message>
        <source>Del</source>
        <translation>Del</translation>
    </message>
    <message>
        <source>&amp;Clean duplicates</source>
        <translation>清除重複項(&amp;C)</translation>
    </message>
    <message>
        <source>&amp;Configure Mnemosyne</source>
        <translation>配置 Mnemosyne(&amp;C)</translation>
    </message>
    <message>
        <source>Getting started</source>
        <translation>入門指引</translation>
    </message>
    <message>
        <source>&amp;Getting started</source>
        <translation>入門指引(&amp;G)</translation>
    </message>
    <message>
        <source>Down, Down</source>
        <translation>Down, Down</translation>
    </message>
    <message>
        <source>Enter</source>
        <translation>Enter</translation>
    </message>
    <message>
        <source>Return</source>
        <translation>Return</translation>
    </message>
    <message>
        <source>Space</source>
        <translation>Space</translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <source>Show statistics</source>
        <translation>察看統計</translation>
    </message>
    <message>
        <source>Show s&amp;tatistics</source>
        <translation>察看統計(&amp;T)</translation>
    </message>
    <message>
        <source>Ctrl+T</source>
        <translation>Ctrl+T</translation>
    </message>
    <message>
        <source>Tip of the day</source>
        <translation>今日說明</translation>
    </message>
    <message>
        <source>&amp;Tip of the day</source>
        <translation>今日說明(&amp;T)</translation>
    </message>
    <message>
        <source>Main toolbar (Mnemosyne)</source>
        <translation>主工具軸 (Mnemosyne)</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>檔案(&amp;F)</translation>
    </message>
    <message>
        <source>&amp;Deck</source>
        <translation>卡片疊(&amp;D)</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>設定(&amp;S)</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>說明(&amp;H)</translation>
    </message>
    <message>
        <source>Ctrl+G</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PreviewItemDlg</name>
    <message>
        <source>&lt;default&gt;</source>
        <translation>&lt;預設&gt;</translation>
    </message>
    <message>
        <source>Question:</source>
        <translation>問題：</translation>
    </message>
</context>
<context>
    <name>PreviewItemFrm</name>
    <message>
        <source>Preview card</source>
        <translation>預覽卡片</translation>
    </message>
    <message>
        <source>Question:</source>
        <translation>問題：</translation>
    </message>
    <message>
        <source>Answer:</source>
        <translation>答案：</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>確認(&amp;O)</translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation>Alt+O</translation>
    </message>
</context>
<context>
    <name>ProductTourFrm</name>
    <message>
        <source>Getting started</source>
        <translation>入門指引</translation>
    </message>
    <message>
        <source>Greetings!

I am Mnemosyne, a type of butterfly named after the Greek goddess of Memory. 

I can make it more efficient for you to memorise and remember answers to questions, by helping you focus on the cards you&apos;re most likely to forget and by not wasting your time on things you know well.

For that, I&apos;ll decide when to ask you the questions, and you&apos;ll need to rate how well you remember the answers.

Let&apos;s look at the meaning of these ratings now.</source>
        <translation>你好！

我是 Mnemosyne，以希臘的記憶女神命名的一種蝴蝶。

我能使你更有效地記住問題的答案，這是通過幫你集中精力于那些你最可能忘記的卡片，而不在你熟知的東西上浪費時間。

為此，我會決定什么時候問你問題，而你則需要為你對答案的記憶好壞打分。

現在讓我們來看看這些評分的含義。</translation>
    </message>
    <message>
        <source>Introduction</source>
        <translation>介紹</translation>
    </message>
    <message>
        <source>Grades range from 0 to 5.

Grades 0 and 1 are used if you don&apos;t know the answer yet, or if you have forgotten it. A card with grade 1 is starting to get more familiar than one with grade 0, and will be repeated less often.

I will keep on asking you these questions until you give them a grade 2 or higher (the exact grade doesn&apos;t matter). Grade 2 basically means that you think you&apos;ll be able to remember the card for at least one or two days. It signals the transition between short and long term memory.

I will schedule this card at some future date, when I think you&apos;ll still be able to remember it with some effort, without having forgotten it completely. This is the most efficient for the learning process.</source>
        <translation>評分範圍從0到5。

如果你還不知道答案，或者你已經忘記了，你就打0分或1分。比起0分來，1分的卡片正開始變得更熟悉，并將較少被重複。

我會不斷問你這些問題，直到你給它們打2分或更高（具體的評分無關緊要）。2分基本表示你認為你能把這張卡片記住至少一兩天。它是短期和長期記憶之間轉換的訊號。

我會把這張卡片安排在未來的某天，當我認為你仍能稍作努力而記起它，而不是完全忘了它。這對學習過程最為有效。</translation>
    </message>
    <message>
        <source>Grades 0-2</source>
        <translation>0-2分</translation>
    </message>
    <message>
        <source>If in the future I ask you the question too soon, and you&apos;re able to remember it without any effort, you rate the card a 5. I&apos;ll take this into account by waiting a lot longer before asking you this question again.

If I get it just right, so that you remember it, albeit with some effort, you use grade 4.

If on the other hand it takes you significant effort to remember the answer, and you think I&apos;ve waited too long to ask you this question, then rate the card 3.

If you fail to remember it altogether, rate it either 0 or 1, and I&apos;ll keep on asking you this question until you think you&apos;ll be able to remember it again for a few days.</source>
        <translation>如果將來我過早地問你問題，而你能毫不費力地記起它，你就給這張卡片打5分。顧及于此，我會等上很長時間再問你這個問題。

如果我做得恰到好處，使你雖需稍作努力，但能記起它，你就打4分。

然而如果你需要費很大勁才能記起答案，你覺得我等了太長時間才問你這個問題，那就打3分。

如果你完全無法記起，就打0或1分，我會不斷問你這個問題，直到你認為你能再次把它記住几天。</translation>
    </message>
    <message>
        <source>Grades 3-5</source>
        <translation>3-5分</translation>
    </message>
    <message>
        <source>If you&apos;re into statistics, I can keep detailed logs of your revisions.

Not only that, but if you want, I can upload transparently a completely anonymous version of these logs to a central site for analysis, so that you can help making me better. In this way, you also contribute to scientific research on long-term memory.

Uncheck the following box if you do not want to do this.</source>
        <translation>要是你對統計感興趣，我可以為你的復習留下詳細的日誌。

不僅如此，如果你希望，我可以把這些日誌的一個完全匿名的版本不知不覺地上傳到一個中心網站用作解析，那你就能幫我變得更好了。以這種方式，你也為長期記憶的科學研究做出了貢獻。

如果你不想做這件事，請取消下面的選框。</translation>
    </message>
    <message>
        <source>Upload anonymous logs</source>
        <translation>上傳匿名日誌</translation>
    </message>
    <message>
        <source>(You can always change this setting later using the &apos;Configure Mnemosyne&apos; menu option.)</source>
        <translation>（以后你始終能變更這項設定，請用“配置 Mnemosyne”功能表項）</translation>
    </message>
    <message>
        <source>Statistics</source>
        <translation>統計</translation>
    </message>
    <message>
        <source>Now you&apos;re ready to start!
&lt;p&gt;
Add new cards by clicking on the icon with the &apos;plus&apos; sign in the top left.
&lt;p&gt;
Remember, there is no need to worry about saving your work, I will do so automatically.
&lt;p&gt;
For best results, I suggest you do your revisions every day, although I&apos;ll try to cope as best I can if you postpone your revisions or if you want to learn ahead of time.
&lt;p&gt;
For more documentation, see http://www.mnemosyne-proj.sourceforge.net.
&lt;p&gt;
Happy learning!</source>
        <translation>現在你已經做好了開始的准備！
&lt;p&gt;
點擊左上角帶有加號的圖像來添加新卡片。
&lt;p&gt;
記住，無需儲存你的工作，我會自動儲存的。
&lt;p&gt;
要獲得最佳結果，我建議你每天做復習，儘管如果你想推遲復習或者提前學習的話，我會盡力應對的。
&lt;p&gt;
要看更多文件，請見 http://www.mnemosyne-proj.sourceforge.net。
&lt;p&gt;
祝你學習愉快！</translation>
    </message>
    <message>
        <source>Ready to start</source>
        <translation>准備開始</translation>
    </message>
</context>
<context>
    <name>QTextEdit2</name>
    <message>
        <source>Insert &amp;image</source>
        <translation>插入圖片(&amp;I)</translation>
    </message>
    <message>
        <source>Ctrl+I</source>
        <translation>Ctrl+I</translation>
    </message>
    <message>
        <source>Insert &amp;sound</source>
        <translation>插入音響(&amp;S)</translation>
    </message>
    <message>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <source>&amp;3-sided input</source>
        <translation>三面匯入(&amp;3)</translation>
    </message>
    <message>
        <source>Image files</source>
        <translation>圖片檔案</translation>
    </message>
    <message>
        <source>Insert image</source>
        <translation>插入圖片</translation>
    </message>
    <message>
        <source>Sound files</source>
        <translation>音響檔案</translation>
    </message>
    <message>
        <source>Insert sound</source>
        <translation>插入音響</translation>
    </message>
</context>
<context>
    <name>StatisticsDlg</name>
    <message>
        <source>Scheduled cards for the next days:

</source>
        <translation type="obsolete">今后几天計划的卡片數：

</translation>
    </message>
    <message>
        <source>In</source>
        <translation>第</translation>
    </message>
    <message>
        <source>day(s) :</source>
        <translation>天：</translation>
    </message>
    <message>
        <source>Number of cards with the following grades:

</source>
        <translation>各個評分的卡片數：

</translation>
    </message>
    <message>
        <source>Grade</source>
        <translation>評分</translation>
    </message>
    <message>
        <source>No current card.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Grade:</source>
        <translation type="unfinished">評分：</translation>
    </message>
    <message>
        <source>Easiness:</source>
        <translation type="unfinished">容易程度：</translation>
    </message>
    <message>
        <source>Repetitions:</source>
        <translation type="unfinished">重複次數：</translation>
    </message>
    <message>
        <source>Lapses:</source>
        <translation type="unfinished">錯過次數：</translation>
    </message>
    <message>
        <source>Days since last repetition:</source>
        <translation type="unfinished">自從上次重複的天數：</translation>
    </message>
    <message>
        <source>Days until next repetition:</source>
        <translation type="unfinished">直到下次重複的天數：</translation>
    </message>
    <message>
        <source>Scheduled cards for next week:

</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>StatisticsFrm</name>
    <message>
        <source>Category</source>
        <translation>分類</translation>
    </message>
    <message>
        <source>Cards</source>
        <translation>卡片</translation>
    </message>
    <message>
        <source>Statistics</source>
        <translation>統計</translation>
    </message>
    <message>
        <source>Schedule</source>
        <translation>計划</translation>
    </message>
    <message>
        <source>Grades</source>
        <translation>評分</translation>
    </message>
    <message>
        <source>Categories</source>
        <translation>分類</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>確認(&amp;O)</translation>
    </message>
    <message>
        <source>Current card</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TipDlg</name>
    <message>
        <source>For optimal results, it&apos;s best to do your repetitions every day.</source>
        <translation>要獲得最佳結果，你最好每天做復習。</translation>
    </message>
    <message>
        <source>If you&apos;ve been away for a few days, don&apos;t worry about your backlog. Do as many cards as you feel like to catch up, the rest will be automatically rescheduled to the future.</source>
        <translation>如果你有几天不在，不必擔心積壓的卡片。要趕回進度，你想復習多少就多少，剩餘的會被自動重新安排到以后。</translation>
    </message>
    <message>
        <source>The &apos;number of grade 0 cards to learn at once&apos; setting determines how many new cards you are trying to learn at the same time. It does &lt;b&gt;not&lt;/b&gt; tell you how many new cards you need to learn per day. You are the judge of that: you can learn more cards or less cards, depending on how you feel.</source>
        <translation>“一次學習0分卡片數量”的設定決定你一次嘗試學習多少新卡片。它&lt;b&gt;不&lt;/b&gt;會告訴你每天需要學習多少新卡片。你是決定者：你可以學習更多或者更少的卡片，取決于你感覺如何。</translation>
    </message>
    <message>
        <source>In summary, try to do your repetitions every day, but don&apos;t worry too much about getting the &apos;scheduled&apos; counter to zero, and certainly not about getting the &apos;Not memorised&apos; counter to zero.</source>
        <translation>總之，儘量每天做復習，但并不是一定要把“計划”的計數器搞到零，更不必把“未記”的計數器搞到零。</translation>
    </message>
    <message>
        <source>Grade 1 cards are different from grade 0 cards in the sense that they show up less often and are not subject to the &apos;number of grade 0 cards to learn at once&apos; setting.</source>
        <translation>1分卡片與0分卡片的不同在于它們更少出現，并且不受“一次學習0分卡片數量”設定的影響。</translation>
    </message>
    <message>
        <source>You can use keyboard shortcuts to do your repetitions. Enter, Return or Space stand for the default action (&apos;Show answer&apos; or &apos;grade 4&apos;). The number keys can be used for grading.</source>
        <translation>你可以使用鍵槃捷徑鍵來做你的復習。轉鍵或白字元鍵代表預設動作（“察看答案”或者“打4分”）。數字鍵可以用于打分。</translation>
    </message>
    <message>
        <source>You can select the categories you wish to study in the &apos;Activate categories&apos; menu option.</source>
        <translation>你可以在“啟動分類”功能表項裡選取你想要學習的分類。</translation>
    </message>
    <message>
        <source>It is recommended to put all your cards in a single database and use categories to organise them. Using &apos;Activate categories&apos; is much more convenient than have to load and unload several databases.</source>
        <translation>建議你把所有卡片都放在一個資料程式庫裡，并用分類來組織它們。比起裝載、卸載多個資料程式庫，使用“啟動分類”要方便多了。</translation>
    </message>
    <message>
        <source>You can import cards in a wide variety of formats: tab delimited txt files, Supermemo files, ... .</source>
        <translation>你可以導入多種格式的卡片：Tab 分隔的字檔檔案，Supermemo 檔案，...。</translation>
    </message>
    <message>
        <source>If you have cards in Word or Excel, export them to tab delimited txt files with UTF-8 unicode encoding to be able to import them into Mnemosyne.</source>
        <translation>如果你在 Word 或 Excel 裡有卡片，請把它們導出為 UTF-8 編碼的 Tab 分隔的字檔檔案，使之能導入到 Mnemosyne 中。</translation>
    </message>
    <message>
        <source>If you want to print out your cards, export them to a txt file which you can then print from your favourite Word processor.</source>
        <translation>如果你想把你的卡片列印出來，請把它們導出為一個字檔檔案，這樣你就可以在你喜歡的文字處理程式裡列印了。</translation>
    </message>
    <message>
        <source>You can share your cards with someone else by exporting them to XML and choosing the &apos;Reset learning data&apos; option on export.</source>
        <translation>你可以跟別人分享你的卡片，只需把它們導出為 XML，并在導出時選取“重置學習資料”選項。</translation>
    </message>
    <message>
        <source>If you study a foreign language with a different script, the default font size is sometimes a bit small. If you want to increase the size of these characters but keep the size of English text, use the &apos;increase size of non-latin characters by X points&apos; option.</source>
        <translation>如果你在學習一門有非拉丁字元的語言（比如中文），預設的字型大小往往太小了。如果你想要增加這些字元的大小而保持英文字檔的大小，請使用“增加非拉丁字元大小X磅(pt)”的選項。</translation>
    </message>
    <message>
        <source>You can add images and sounds to your cards. Right-click on the question or answer field when editing a card to bring up a pop-up menu to do so.</source>
        <translation>你可以給你的卡片添加圖片和音響。在編輯卡片時，右擊問題或答案框，就會出現一個即現式功能表來讓你完成添加。</translation>
    </message>
    <message>
        <source>It is recommended to keep your sound and image files inside your .mnemosyne directory. That way, it&apos;s easier to transfer your data between different computers.</source>
        <translation>建議你把你的音響和圖片檔案放在你的 .mnemosyne 目錄裡。那樣的話，要在不同電腦之間傳送你的資料就更容易了。</translation>
    </message>
    <message>
        <source>When adding a three-sided card, two regular cards will be created. One with as question the written form and as answer the pronunciation and the translation, and one with as question the translation and as answer the written form and the pronunciation.</source>
        <translation>在添加三面卡片時，會有兩張常規卡片被建立。一張以文字形式作為問題，發音和翻譯作為答案，另一張則以翻譯作為問題，文字形式和發音作為答案。</translation>
    </message>
    <message>
        <source>You can use basic HTML tags in your cards to control their appearance.</source>
        <translation>你可以在你的卡片裡使用基本的 HTML 標簽來控制外觀。</translation>
    </message>
    <message>
        <source>Mnemosyne can use LaTeX to render mathematical formulas, e.g. &lt;$&gt;x^2+y^2=z^2&lt;/$&gt;. (For this, you need LaTeX and dvipng installed.)</source>
        <translation>Mnemosyne 可以使用 LaTeX 來表達數學公式，如 &lt;$&gt;x^2+y^2=z^2&lt;/$&gt;。（為此，你需要裝有 LaTeX 和 dvipng。）</translation>
    </message>
    <message>
        <source>The best way to backup your data is to copy your .mnemosyne directory (if you follow the recommended procedure to keep all your files there) and move it to a different drive. Mnemosyne keeps automatic XML-based backups in .mnemosyne/backups, but that won&apos;t help you if that drive dies... </source>
        <translation>復本你的資料的最佳方法是複製你的 .mnemosyne 目錄（如果你遵循建議步驟而把你的所有檔案都放在那兒）并把複本移動到另一個磁碟機。Mnemosyne 會自動在 .mnemosyne/backups 裡儲存基于 XML 的復本， 但要是那個磁碟機完蛋的話，那個是幫不了你的... </translation>
    </message>
    <message>
        <source>You can run Mnemosyne from a USB key. Copy C:\Program Files\Mnemosyne to your USB key, and then copy the .mnemosyne directory from your home directory to inside the Mnemosyne directory on the USB key.</source>
        <translation>你可以從U盤上執行 Mnemosyne。把 C:\Program Files\Mnemosyne 複製到你的U盤上，然后把 .mnemosyne 目錄從你的主目錄複製到U盤的 Mnemosyne 目錄裡。</translation>
    </message>
    <message>
        <source>If you use Mnemosyne on multiple computers, there is a handy tool called Unison to help you synchronise your data. See the Mnemosyne website for more information.</source>
        <translation>如果你在多台電腦上使用 Mnemosyne，有個好用的工具叫 Unison 能幫你同步你的資料。更多資訊請見 Mnemosyne 網站。</translation>
    </message>
    <message>
        <source>You can sort the cards in the &apos;Edit Deck&apos; dialog by answer or by category by clicking on the corresponding column title. Clicking again changes the sort order.</source>
        <translation>你可以在“編輯卡片疊”對話方塊裡，通過點擊相應的列名，將卡片按答案或分類排序。</translation>
    </message>
    <message>
        <source>If you want more fine-grained control over LaTeX&apos;s behaviour, see the explanation of the &lt;$$&gt;...&lt;/$$&gt; and &lt;latex&gt;...&lt;/latex&gt; tags on Mnemosyne&apos;s website.</source>
        <translation>如果你想對 LaTeX 的行為有更細致的控制， 請見 Mnemosyne 的網站上對 &lt;$$&gt;...&lt;/$$&gt; 和 &lt;latex&gt;...&lt;/latex&gt; 標簽的解譯。</translation>
    </message>
    <message>
        <source>Advanced users can customise more of Mnemosyne by editing the config.py file in their .mnemosyne directory. They can also install plugins to customise Mnemosyne even further.</source>
        <translation>進階用戶可以通過編輯他們的 .mnemosyne 目錄裡的 config.py 檔案來對 Mnemosyne 做更多自訂。他們也可以裝載插件來進一步自訂 Mnemosyne。</translation>
    </message>
</context>
<context>
    <name>TipFrm</name>
    <message>
        <source>Tip of the day</source>
        <translation>今日說明</translation>
    </message>
    <message>
        <source>&lt;b&gt;Did you know...?&lt;/b&gt;</source>
        <translation>&lt;b&gt;你知道嗎？&lt;/b&gt;</translation>
    </message>
    <message>
        <source>&amp;Show tips on startup</source>
        <translation>啟動時察看說明(&amp;S)</translation>
    </message>
    <message>
        <source>Alt+S</source>
        <translation>Alt+S</translation>
    </message>
    <message>
        <source>&amp;Previous</source>
        <translation>前一條(&amp;P)</translation>
    </message>
    <message>
        <source>Alt+P</source>
        <translation>Alt+P</translation>
    </message>
    <message>
        <source>&amp;Next</source>
        <translation>下一條(&amp;N)</translation>
    </message>
    <message>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>關閉(&amp;C)</translation>
    </message>
    <message>
        <source>Alt+C</source>
        <translation>Alt+C</translation>
    </message>
</context>
</TS>
